==> burnt-4.6.x-1.x-dev.tar.gz: burnt/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

  <head>
    <title><?php print $head_title ?></title>
    <meta http-equiv="Content-Style-Type" content="text/css" />
    <?php print $head ?>
    <?php print $styles ?>
  </head>

<body <?php print theme("onload_attribute"); ?>>
<div id="container">
	<div id="header">
    <?php if ($site_name) : ?>
      <h1>
        <?php if ($site_name) { ?><h1 class='site-name'><a href="./" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?>
      </h1>
    <?php endif;?>
    <?php if ($site_slogan) { ?><p><?php print $site_slogan ?></p><?php } ?>	 
      <?php if ($search_box) { ?><form action="<?php print $search_url ?>" method="post">
        <div id="search">
          <input class="form-text" type="text" size="15" value="" name="edit[keys]" alt="<?php print $search_description ?>" />
          <input class="form-submit" type="submit" value="<?php print $search_button_text ?>" />
        </div>
      </form><?php } ?>
	</div>

  <?php if ($sidebar_left) { ?>
	  <div id="sidebar-left">
      <?php print $sidebar_left ?>
      <?php if (($sidebar_right) && (burnt_is_admin())) { ?>
        <?php print $sidebar_right ?>
      <?php } ?>
    </div>
  <?php } ?>

 	<div id="content" <?php if (burnt_is_admin()) { ?>class="admin"<?php } ?>>
    <?php print $breadcrumb ?>
    <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
    <?php print $help ?>
    <?php print $messages ?>
    <h1 class="title"><?php print $title ?></h1>
    <div class="tabs"><?php print $tabs ?></div>
    <?php print $content; ?>
  </div>

  <?php if (($sidebar_right) && (!burnt_is_admin())) { ?>
	  <div id="sidebar-right">
      <?php print $sidebar_right ?>
    </div>
  <?php } ?>

	  
	<div id="footer">
    <p><?php print $footer_message ?>
    <?php print $closure ?></p>
  </div>
</div>

</body>
</html>

==> burnt-4.7.x-1.x-dev.tar.gz: burnt/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

  <head>
    <title><?php print $head_title ?></title>
    <meta http-equiv="Content-Style-Type" content="text/css" />
    <?php print $head ?>
    <?php print $styles ?>
  </head>

<body <?php print theme("onload_attribute"); ?>>
<div id="container">
	<div id="header">
    <?php if ($site_name) : ?>
      <h1>
        <?php if ($site_name) { ?><h1 class='site-name'><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?>
      </h1>
    <?php endif;?>
    <?php if ($site_slogan) { ?><p><?php print $site_slogan ?></p><?php } ?>	 
    <?php print $search_box ?>
	</div>

  <?php if ($sidebar_left) { ?>
	  <div id="sidebar-left">
      <?php print $sidebar_left ?>
      <?php if (($sidebar_right) && (burnt_is_admin())) { ?>
        <?php print $sidebar_right ?>
      <?php } ?>
    </div>
  <?php } ?>

 	<div id="content" <?php if (burnt_is_admin()) { ?>class="admin"<?php } ?>>
    <?php print $breadcrumb ?>
    <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
    <?php print $help ?>
    <?php print $messages ?>
    <h1 class="title"><?php print $title ?></h1>
    <div class="tabs"><?php print $tabs ?></div>
    <?php print $content; ?>
  </div>

  <?php if (($sidebar_right) && (!burnt_is_admin())) { ?>
	  <div id="sidebar-right">
      <?php print $sidebar_right ?>
    </div>
  <?php } ?>

	  
	<div id="footer">
    <p><?php print $footer_message ?>
    <?php print $closure ?></p>
  </div>
</div>

</body>
</html>
